@@ -59,7 +59,8 @@ if __name__ == "__main__":
     #m = "Mage Solar : Powertec Plus 285-6 PL"
     #m = "Mage Solar : Powertec Plus 245-6 PL *"
     m = "Mage Solar : USA Powertec Plus 250-6 MNCS"
-    ms = modules.module(m)
-    system = inverters.inverter("Refusol: 20 kW 480V",modules.PvArray(ms,[{'series':11,'parallel':6}]))
+    ms = modules.Module(m)
+    system = inverters.Inverter("Refusol: 20 kW 480V",modules.PvArray(ms,[{'series':11,'parallel':6}]))
     #print fill(system,zc)
     print generate_options("Refusol: 20 kW 480V",m,zc)
+    print generate_options("Enphase Energy: M215-60-2LL-IG-S2X (240V) 240V",m,zc)
